@@ -51,7 +51,7 @@ function log_out_of_https() {
 
 function show_ssl_link_version() {
 
-   return '2.0.8';
+   return '2.1';
 
 }
 
